---
jupyter:
  jupytext:
    text_representation:
      extension: .Rmd
      format_name: rmarkdown
      format_version: '1.1'
      jupytext_version: 1.1.1
  kernelspec:
    display_name: Python 3
    language: python
    name: python3
---

```{python nbsphinx=hidden}
import pandas as pd
pd.set_option("display.max_rows", 5)
```

## Transmute

This function is equivalent doing a `mutate`, followed by a `select` to keep the recently defined columns. Currently the way it works is...

* Positional arguments are used to select columns
* Named arguments are used as in mutate

```{python}
from siuba import _, transmute
from siuba.data import mtcars
```

```{python}
mtcars >> transmute(_.cyl, _.mpg, hp_per_cyl = _.hp / _.cyl)
```
